==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccioneu un o més dispositius</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Càmera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Alterna a finestra</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Alterna a pantalla completa</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Compte enrere</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccioneu un o més dispositius</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>L&apos;enregistrament no s&apos;ha iniciat, no hi ha prou espai lliure al disc.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>S’ha abastat el límit d’espai lliure al disc.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límit d&apos;espai lliure al disc</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>L&apos;enregistrament s&apos;ha aturat, no hi ha prou espai lliure al disc.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>No s’ha trobat cap gestor de fitxers.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instal·leu un gestor de fitxers.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>La sessió d’escriptori és una sessió de Wayland</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Fins al moment no s&apos;admet el Wayland. Una captura en vídeo mostrarà una pantalla en negre. Si us plau, tanqueu la sessió i iniceu una sessió d&apos;escriptori amb X11.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Codi font</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Lloc web</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduccions</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Feu una donació</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>S&apos;ha detectat una sessió d&apos;escriptori de Wayland</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Obre el fitxer</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Àrea</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Gir horitzontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Gir vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertida</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanc i negre</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Elimina el marc de la finestra</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Ajustaments de la càmera</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Àrea</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliació</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Compte enrere</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Mida del vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espai lliure al disc:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Temps enregistrat:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Àudio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogrames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Còdec del vídeo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Còdec de l&apos;àudio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualitat</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No enregistris el cursor del ratolí</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minut</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Inicia el temporitzador</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Atura l&apos;enregistrament després de</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Hores</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuts</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segons</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Camí del vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límit d&apos;espai lliure al disc</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostra a la safata del sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segona espera abans d&apos;enregistrar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Comprova si hi ha actualitzacions</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Càmera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertida</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Envia el registre</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>Ctrl+Majús.+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>Ctrl+Majús.+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>Ctrl+Majús.+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reprodueix el darrer enregistrament</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Obre una carpeta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>Ctrl+Majús.+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimitza en iniciar l&apos;enregistrament</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Inicia minimitzat</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Gir horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Gir vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanc i negre</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Elimina el marc de la finestra</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Feu una donació</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Restableix tots els ajustament al següent inici</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Drets d&apos;autor i llicència de les imatges</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Emissió de la pantalla</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registre</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Drets d&apos;autor i llicència de les imatges</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Obre un fitxer</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Fotograma anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Fotograma següent</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenci</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mou el menú</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccioneu un o més dispositius</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Càmera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Alterna a finestra</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Alterna a pantalla completa</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccioneu un o més dispositius</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>No s’ha trobat cap gestor de fitxers.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instal·leu un gestor de fitxers.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>L&apos;enregistrament no s&apos;ha iniciat, no hi ha prou espai lliure al disc.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>S’ha abastat el límit d’espai lliure al disc.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límit d&apos;espai lliure al disc</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>L&apos;enregistrament s&apos;ha aturat, no hi ha prou espai lliure al disc.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>No s’ha trobat cap gestor de fitxers.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instal·leu un gestor de fitxers.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Codi font</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Lloc web</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduccions</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Feu una donació</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccioneu un o més dispositius</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Àrea</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Càmera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliació</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Gir horitzontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Gir vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertida</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanc i negre</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Elimina el marc de la finestra</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Ajustaments de la càmera</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Àrea</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliació</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Compte enrere</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Mida del vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espai lliure al disc:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Temps enregistrat:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Àudio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogrames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Còdec del vídeo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Còdec de l&apos;àudio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualitat</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No enregistris el cursor del ratolí</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minut</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Inicia el temporitzador</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Atura l&apos;enregistrament després de</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Hores</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuts</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segons</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Camí del vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límit d&apos;espai lliure al disc</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostra a la safata del sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segona espera abans d&apos;enregistrar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Comprova si hi ha actualitzacions</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Càmera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertida</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Envia el registre</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>Ctrl+Majús.+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>Ctrl+Majús.+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>Ctrl+Majús.+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reprodueix el darrer enregistrament</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Obre una carpeta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>Ctrl+Majús.+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimitza en iniciar l&apos;enregistrament</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Inicia minimitzat</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Gir horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Gir vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanc i negre</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Elimina el marc de la finestra</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Feu una donació</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Restableix tots els ajustaments en el proper inici</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Drets d&apos;autor i llicència de les imatges</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Emissió de la pantalla</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registre</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Drets d&apos;autor i llicència de les imatges</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Obre un fitxer</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Fotograma anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Fotograma següent</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenci</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mou el menú</translation>
    </message>
</context>
</TS>
